﻿using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;

namespace SimpleGrid
{
	public partial class SimpleGridViewController : UIViewController
	{
		#region Members

		IGGridView gridView;

		IGGridViewDataSourceHelper dsh;

		List<cSimpleGrid> lstGridItems;

		#endregion

		#region Constructor

		public SimpleGridViewController () : base ("SimpleGridViewController", null)
		{
		}

		#endregion

		#region View Controller Methods

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			//Next, create a new instance of the grid view and place it on the view.
			gridView = new IGGridView (new System.Drawing.RectangleF (0, 0, this.View.Bounds.Width, this.View.Bounds.Height), IGGridViewStyle.IGGridViewStyleDefault);
			gridView.AutoresizingMask = UIViewAutoresizing.All;

			this.View.Add (gridView);


			// create some objects and fill a list
			var obj1 = new cSimpleGrid();
			obj1["Motion"] = 1;
			obj1["Left"] = 10;
			obj1["Right"] = 100;
			var obj2 = new cSimpleGrid();
			obj2["Motion"] = 2;
			obj2["Left"] = 20;
			obj2["Right"] = 200;
			var obj3 = new cSimpleGrid();
			obj3["Motion"] = 3;
			obj3["Left"] = 30;
			obj3["Right"] = 300;

			lstGridItems = new List<cSimpleGrid>(new cSimpleGrid[]{ obj1, obj2, obj3 });



			//Setup the Grid
			SetupGrid ();
		}

		#endregion

		#region Methods

		/// <summary>
		/// This method is responsible for the layour and populate of the grid view
		/// </summary>
		private bool SetupGrid ()
		{
			//First, create a new return variable
			bool bReturn = true;

			try {

				// We're using the basic IGGridViewDataSourceHelper
				// since our data will be displayed in a standard datagrid
				dsh = new IGGridViewDataSourceHelper();

				// Since we are manually creating columns, turn off auto-generation
				dsh.AutoGenerateColumns = false;


				customSimpleGridColumnDefinition motion = new customSimpleGridColumnDefinition("Motion");
				customSimpleGridColumnDefinition left = new customSimpleGridColumnDefinition("Left");
				customSimpleGridColumnDefinition right = new customSimpleGridColumnDefinition("Right");

				dsh.ColumnDefinitions.Add(motion);
				dsh.ColumnDefinitions.Add(left);
				dsh.ColumnDefinitions.Add(right);

				//This is causing the grid to not appear, when using dynamic columns
				dsh.GroupingKey = @"Motion";

				//Next, set the data object
				dsh.Data = lstGridItems.ToArray();

				dsh.AllowEditing = true;

				//Set the DataSource
				gridView.DataSource = dsh;

				gridView.RowReordering = true;

				//Turn off empty rows
				gridView.EmptyRows = false;

				//Update gridView
				gridView.UpdateData ();

			} catch {
				//Error building the grid, return false.
				bReturn = false;
			}

			//Finally, return the return variable
			return bReturn;
		}
		#endregion

		public class customSimpleGridColumnDefinition : IGGridViewColumnDefinition
		{
			string _fieldKey;

			public customSimpleGridColumnDefinition(string key):base()
			{
				_fieldKey = key;
			}

			public override string FieldKey {
				get {
					return _fieldKey;
				}
			}

			public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
			{
				IGGridViewCell cell = (IGGridViewCell)gridView.DequeueReusableCell ("simpleGridCell");

				if (cell == null) {
					cell = new IGGridViewCell ("simpleGridCell");
				}

				cSimpleGrid dataRow = (cSimpleGrid)dataSource.ResolveDataObjectForRow (path);

			
				//I'm not sure if I need to use reflection here or if  I need to do something else
				cell.TextLabel.Text = dataRow [_fieldKey].ToString ();

			
				return cell;
			}
		}

	}
}

